==> izpack-api-5.1.3-sources.jar: com/izforge/izpack/api/data/ScriptParserConstant.java <==
/*
 * IzPack - Copyright 2001-2012 Julien Ponge, All Rights Reserved.
 *
 * http://izpack.org/
 * http://izpack.codehaus.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.izforge.izpack.api.data;

public class ScriptParserConstant
{
    /**
     * The Java home path.
     */
    public static final String JAVA_HOME = "JAVA_HOME";
    /**
     * The ClassPath.
     */
    public static final String CLASS_PATH = "CLASS_PATH";
    /**
     * The user home path.
     */
    public static final String USER_HOME = "USER_HOME";
    /**
     * The user name.
     */
    public static final String USER_NAME = "USER_NAME";
    /**
     * The hostname.
     */
    public static final String HOST_NAME = "HOST_NAME";
    /**
     * The ip address.
     */
    public static final String IP_ADDRESS = "IP_ADDRESS";
    /**
     * The file separator character.
     */
    public static final String FILE_SEPARATOR = "FILE_SEPARATOR";
    /**
     * The application name.
     */
    public static final String APP_NAME = "APP_NAME";
    /**
     * The application URL.
     */
    public static final String APP_URL = "APP_URL";
    /**
     * The application version.
     */
    public static final String APP_VER = "APP_VER";
    /**
     * The language IS03 code.
     */
    public static final String ISO3_LANG = "ISO3_LANG";
    
    /**
     * The language IS0 code.
     */
    public static final String ISO2_LANG = "ISO2_LANG";
    /**
     * The language code as _ll_CC like used with ResourceBoundle.
     */
    public static final String LOCALE = "LOCALE_IDENTIFIER";
}

==> izpack-api-5.2.4-sources.jar: com/izforge/izpack/api/data/ScriptParserConstant.java <==
/*
 * IzPack - Copyright 2001-2012 Julien Ponge, All Rights Reserved.
 *
 * http://izpack.org/
 * http://izpack.codehaus.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.izforge.izpack.api.data;

public class ScriptParserConstant
{
    /**
     * The Java home path.
     */
    public static final String JAVA_HOME = "JAVA_HOME";
    /**
     * The ClassPath.
     */
    public static final String CLASS_PATH = "CLASS_PATH";
    /**
     * The user home path.
     */
    public static final String USER_HOME = "USER_HOME";
    /**
     * The user name.
     */
    public static final String USER_NAME = "USER_NAME";
    /**
     * The hostname.
     */
    public static final String HOST_NAME = "HOST_NAME";
    /**
     * The canonical hostname (FQDN).
     */
    public static final String CANONICAL_HOST_NAME = "CANONICAL_HOST_NAME";
    /**
     * The ip address.
     */
    public static final String IP_ADDRESS = "IP_ADDRESS";
    /**
     * The file separator character.
     */
    public static final String FILE_SEPARATOR = "FILE_SEPARATOR";
    /**
     * The application name.
     */
    public static final String APP_NAME = "APP_NAME";
    /**
     * The application URL.
     */
    public static final String APP_URL = "APP_URL";
    /**
     * The application version.
     */
    public static final String APP_VER = "APP_VER";
    /**
     * The language IS03 code.
     */
    public static final String ISO3_LANG = "ISO3_LANG";
    
    /**
     * The language IS0 code.
     */
    public static final String ISO2_LANG = "ISO2_LANG";
    /**
     * The language code as _ll_CC like used with ResourceBoundle.
     */
    public static final String LOCALE = "LOCALE_IDENTIFIER";
}
